==> mcss-0.0.35.tar.gz: mcss-0.0.35/make-deb.sh <==
#!/bin/sh

PKGBASE=$(cat NAME)
VERSION=$(cat VERSION)
PKGNAME=$PKGBASE-$VERSION
CTRLFILE=control
LICENSE="/usr/share/doc/$PKGNAME/COPYING"
README="/usr/share/doc/$PKGNAME/README"
MAINTAINER=$(cat $CTRLFILE | egrep '^%vendor' | sed 's/%vendor //')
LASTVERSION=$(echo $VERSION | cut -f 3 -d '.')
LASTVERSION=$(echo "${LASTVERSION}-1" | bc)
LASTVERSION="$(echo $VERSION | cut -f1,2 -d '.').${LASTVERSION}"
PYPKGNAME=python-${PKGNAME}
PYPKGBASE=python-${PKGBASE}
PYDEPS="libboost-python1.40.0"

echo "creating ${PKGBASE} debian packages..."

echo "creating debian package..."
CWD=$(pwd)
TMPDIR=/tmp/$PKGNAME
TMPFILE=${TMPDIR}/${PKGNAME}.tmp
LOGFILE=${TMPDIR}/${PKGNAME}.log
ARCH=$(dpkg --print-architecture)

echo "building source..."
rm -rf $TMPDIR &&
mkdir $TMPDIR &&
./autogen.sh &>> ${LOGFILE} &&
./configure --prefix=$TMPDIR/build &>> ${LOGFILE} &&
make clean &>> ${LOGFILE} &&
make all install &>> ${LOGFILE}
if [ $? != 0 ]
then
	echo "error: couldn't build source"
	exit 1
fi

# fix paths
STRING=$(echo "$TMPDIR/build" | sed 's/\//\\\//g') &&
for i in lib/pkgconfig/$PKGBASE.pc lib/lib$PKGBASE.la
do
	cat $TMPDIR/build/$i | sed "s/$STRING/\/usr/g" > $TMPFILE &&
	mv $TMPFILE $TMPDIR/build/$i
	if [ $? != 0 ]
	then
		echo "error: couldn't fix paths"
		exit 1
	fi
done
if [ $? != 0 ]
then
	exit 1
fi

# create control file
echo "creating binary debian package..."
# create control file header
cp $CTRLFILE $TMPDIR/$PKGNAME.list &&
cat << EOF >> $TMPDIR/$PKGNAME.list &&
%product $PKGNAME
%copyright $LICENSE
%version $VERSION
%readme $README
%replaces ${PKGBASE}-${LASTVERSION}
EOF

# create filelist
mkepmlist -g root -u root --prefix /usr $TMPDIR/build >> $TMPDIR/$PKGNAME.list &&
cd $TMPDIR &&
epm -a $ARCH --output-dir . -v -f deb -n $PKGNAME &>> ${LOGFILE} &&
mv ${PKGNAME}-$VERSION.deb $CWD/${PKGNAME}_${VERSION}_$ARCH.deb &&
cd $CWD
if [ $? != 0 ]
then
	echo "error: couldn't create binary package"
	exit 1
fi

# make source package
echo "creating source package..."
make dist &>> ${LOGFILE} &&
cd $TMPDIR &&
tar -xzvf $CWD/$PKGBASE-$VERSION.tar.gz &> /dev/null &&
mv $PKGBASE-$VERSION $PKGBASE-$VERSION-$VERSION &&
cd $PKGBASE-$VERSION-$VERSION &&
dpkg -e $CWD/${PKGNAME}_${VERSION}_$ARCH.deb &> /dev/null &&
mv DEBIAN debian &&
cat debian/control | egrep '(^Package)|(^Maintainer)|(^Description)' > debian/1 &&
mv debian/1 debian/control &&
cat << EOF >> debian/control &&
Source: $PKGNAME
Architecture: any
Section: science
Priority: optional
EOF
cat << EOF > debian/changelog &&
$PKGNAME ($VERSION) unstable; urgency=low
  * comment here.

 -- $MAINTAINER  $(date '+%a, %d %b %Y %T %z')
EOF
cd $TMPDIR &&
dpkg-source -b $PKGBASE-$VERSION-$VERSION &>> ${LOGFILE} &&
mv $PKGBASE-${VERSION}_$VERSION.tar.gz $PKGBASE-${VERSION}_$VERSION.dsc $CWD/ &&
cd $CWD
if [ $? != 0 ]
then
	echo "error: couldn't create source package"
	exit 1
fi

# make meta package
echo "creating meta package..."
# create control file
mkdir -p $TMPDIR/$PKGBASE/DEBIAN &&
cat << EOF > $TMPDIR/$PKGBASE/DEBIAN/control &&
Package: $PKGBASE
Version: $VERSION
Section: science
Priority: optional
Architecture: all
Depends: $PKGNAME
Replaces: $PKGBASE (<< $VERSION)
EOF
cat $CTRLFILE | egrep '^%vendor' | sed 's/%vendor/Maintainer:/' >> $TMPDIR/$PKGBASE/DEBIAN/control &&
cat $CTRLFILE | egrep '^%description' | sed 's/%description/Description:/' >> $TMPDIR/$PKGBASE/DEBIAN/control &&

# make meta package
cd $TMPDIR &&
dpkg-deb --build $PKGBASE &>> ${LOGFILE} &&
mv $PKGBASE.deb $CWD/${PKGBASE}_${VERSION}_all.deb &&
cd $CWD
if [ $? != 0 ]
then
	echo "error: couldn't create meta package"
	exit 1
fi

echo "creating python package..."
cd ${CWD}/python &&
# debian control files
rm -rf debian &&
mkdir debian &&
# changelog
cat << EOF > debian/changelog &&
$PYPKGNAME ($VERSION) unstable; urgency=low
  * comment here.

 -- $MAINTAINER  $(date '+%a, %d %b %Y %T %z')
EOF
# compat
echo $(dpkg -p debhelper | egrep '^Version:' | cut -f 2 -d ' ' | cut -f 1 -d '.') > debian/compat &&
# control
cat << EOF > debian/control &&
Source: ${PYPKGNAME}
Section: science
Priority: optional
Maintainer: ${MAINTAINER}
Build-Depends: debhelper (>=7.0.0), python-support (>= 0.6), cdbs (>= 0.4.49)
Standards-Version: 3.8.3.0

Package: ${PYPKGNAME}
Architecture: ${ARCH}
Depends: \${misc:Depends}, \${python:Depends}, ${PKGNAME}, ${PYDEPS}
Description: ${PKGNAME} python bindings.
EOF
# copyright
cp ../COPYING debian/copyright &&
# rules
cat << EOF > debian/rules &&
#!/usr/bin/make -f
# -*- makefile -*-

DEB_PYTHON_SYSTEM := pysupport

include /usr/share/cdbs/1/rules/debhelper.mk
include /usr/share/cdbs/1/class/python-distutils.mk
include /usr/share/cdbs/1/rules/simple-patchsys.mk
EOF
chmod a+x debian/rules &&
# pyversion
echo "2.5" > debian/pyversions &&
# shlibs.local
LIBFILE=$(whereis libecsb | sed 's/\ /\n/g' | egrep "\.so$" | head -n 1) &&
for i in $(ldd ${LIBFILE} | sed 's/^\t//g' | cut -f 1 -d ' ' | sed 's/\.so\.[0-9\.]*$//g')
do
	echo "libecsb 0 $(basename $i)," >> debian/shlibs.local
done &&
LIBFILE=$(whereis libmcss | sed 's/\ /\n/g' | egrep "\.so$" | head -n 1) &&
for i in $(ldd ${LIBFILE} | sed 's/^\t//g' | cut -f 1 -d ' ' | sed 's/\.so\.[0-9\.]*$//g')
do
	echo "libmcss 0 $(basename $i)," >> debian/shlibs.local
done &&
LIBSBML=$(whereis libsbml | sed 's/\ /\n/g' | egrep "\.so$" | head -n 1) &&
for i in $(ldd ${LIBFILE} | sed 's/^\t//g' | cut -f 1 -d ' ' | sed 's/\.so\.[0-9\.]*$//g')
do
	echo "libsbml 4 $(basename $i)," >> debian/shlibs.local
done &&

# make package
cd .. &&
./configure --enable-python=yes &>> ${LOGFILE} &&
cd python &&
make &>> ${LOGFILE} &&
python setup.py sdist --dist-dir=../ &>> ${LOGFILE} &&
dpkg-buildpackage -uc -b -rfakeroot &>> ${LOGFILE} &&
cd ${CWD} &&
rm -rf $TMPDIR
if [ $? != 0 ]
then
	echo "error: couldn't create python binary package"
	exit 1
fi

# make meta package
echo "making python meta package..."
# create control file
mkdir -p $TMPDIR/$PYPKGBASE/DEBIAN &&
cat << EOF > $TMPDIR/$PYPKGBASE/DEBIAN/control &&
Package: $PYPKGBASE
Version: $VERSION
Section: science
Priority: optional
Architecture: all
Depends: $PYPKGNAME
Replaces: $PYPKGBASE (<< $VERSION)
EOF
cat $CTRLFILE | egrep '^%vendor' | sed 's/%vendor/Maintainer:/' >> $TMPDIR/$PYPKGBASE/DEBIAN/control &&
cat $CTRLFILE | egrep '^%description' | sed 's/%description/Description:/' >> $TMPDIR/$PYPKGBASE/DEBIAN/control &&

# make meta package
cd $TMPDIR &&
dpkg-deb --build $PYPKGBASE &>> ${LOGFILE} &&
mv $PYPKGBASE.deb $CWD/${PYPKGBASE}_${VERSION}_all.deb &&
cd $CWD &&
rm -rf $TMPDIR
if [ $? != 0 ]
then
	echo "error: couldn't create python meta package"
	exit 1
fi

# all done
echo "all ${PKGBASE} packages built ok"

==> mcss-0.0.39.tar.gz: mcss-0.0.39/make-deb.sh <==
#!/bin/sh

PKGBASE=$(cat NAME)
VERSION=$(cat VERSION)
PKGNAME=$PKGBASE-$VERSION
CTRLFILE=control
LICENSE="/usr/share/doc/$PKGNAME/COPYING"
README="/usr/share/doc/$PKGNAME/README"
MAINTAINER=$(cat $CTRLFILE | egrep '^%vendor' | sed 's/%vendor //')
LASTVERSION=$(echo $VERSION | cut -f 3 -d '.')
LASTVERSION=$(echo "${LASTVERSION}-1" | bc)
LASTVERSION="$(echo $VERSION | cut -f1,2 -d '.').${LASTVERSION}"
PYPKGNAME=python-${PKGNAME}
PYPKGBASE=python-${PKGBASE}
PYDEPS="libboost-python1.40.0"

echo "creating ${PKGBASE} debian packages..."

echo "creating debian package..."
CWD=$(pwd)
TMPDIR=/tmp/$PKGNAME
TMPFILE=${TMPDIR}/${PKGNAME}.tmp
LOGFILE=${TMPDIR}/${PKGNAME}.log
ARCH=$(dpkg --print-architecture)

echo "building source..."
rm -rf $TMPDIR &&
mkdir $TMPDIR &&
./autogen.sh &>> ${LOGFILE} &&
./configure --prefix=$TMPDIR/build &>> ${LOGFILE} &&
make clean &>> ${LOGFILE} &&
make all install &>> ${LOGFILE}
if [ $? != 0 ]
then
	echo "error: couldn't build source"
	exit 1
fi

# fix paths
STRING=$(echo "$TMPDIR/build" | sed 's/\//\\\//g') &&
for i in lib/pkgconfig/$PKGBASE.pc lib/lib$PKGBASE.la
do
	cat $TMPDIR/build/$i | sed "s/$STRING/\/usr/g" > $TMPFILE &&
	mv $TMPFILE $TMPDIR/build/$i
	if [ $? != 0 ]
	then
		echo "error: couldn't fix paths"
		exit 1
	fi
done
if [ $? != 0 ]
then
	exit 1
fi

# create control file
echo "creating binary debian package..."
# create control file header
cp $CTRLFILE $TMPDIR/$PKGNAME.list &&
cat << EOF >> $TMPDIR/$PKGNAME.list &&
%product $PKGNAME
%copyright $LICENSE
%version $VERSION
%readme $README
%replaces ${PKGBASE}-${LASTVERSION}
EOF

# create filelist
mkepmlist -g root -u root --prefix /usr $TMPDIR/build >> $TMPDIR/$PKGNAME.list &&
cd $TMPDIR &&
epm -a $ARCH --output-dir . -v -f deb -n $PKGNAME &>> ${LOGFILE} &&
mv ${PKGNAME}-$VERSION.deb $CWD/${PKGNAME}_${VERSION}_$ARCH.deb &&
cd $CWD
if [ $? != 0 ]
then
	echo "error: couldn't create binary package"
	exit 1
fi

# make source package
echo "creating source package..."
make dist &>> ${LOGFILE} &&
cd $TMPDIR &&
tar -xzvf $CWD/$PKGBASE-$VERSION.tar.gz &> /dev/null &&
mv $PKGBASE-$VERSION $PKGBASE-$VERSION-$VERSION &&
cd $PKGBASE-$VERSION-$VERSION &&
dpkg -e $CWD/${PKGNAME}_${VERSION}_$ARCH.deb &> /dev/null &&
mv DEBIAN debian &&
cat debian/control | egrep '(^Package)|(^Maintainer)|(^Description)' > debian/1 &&
mv debian/1 debian/control &&
cat << EOF >> debian/control &&
Source: $PKGNAME
Architecture: any
Section: science
Priority: optional
EOF
cat << EOF > debian/changelog &&
$PKGNAME ($VERSION) unstable; urgency=low
  * comment here.

 -- $MAINTAINER  $(date '+%a, %d %b %Y %T %z')
EOF
cd $TMPDIR &&
dpkg-source -b $PKGBASE-$VERSION-$VERSION &>> ${LOGFILE} &&
mv $PKGBASE-${VERSION}_$VERSION.tar.gz $PKGBASE-${VERSION}_$VERSION.dsc $CWD/ &&
cd $CWD
if [ $? != 0 ]
then
	echo "error: couldn't create source package"
	exit 1
fi

# make meta package
echo "creating meta package..."
# create control file
mkdir -p $TMPDIR/$PKGBASE/DEBIAN &&
cat << EOF > $TMPDIR/$PKGBASE/DEBIAN/control &&
Package: $PKGBASE
Version: $VERSION
Section: science
Priority: optional
Architecture: all
Depends: $PKGNAME
Replaces: $PKGBASE (<< $VERSION)
EOF
cat $CTRLFILE | egrep '^%vendor' | sed 's/%vendor/Maintainer:/' >> $TMPDIR/$PKGBASE/DEBIAN/control &&
cat $CTRLFILE | egrep '^%description' | sed 's/%description/Description:/' >> $TMPDIR/$PKGBASE/DEBIAN/control &&

# make meta package
cd $TMPDIR &&
dpkg-deb --build $PKGBASE &>> ${LOGFILE} &&
mv $PKGBASE.deb $CWD/${PKGBASE}_${VERSION}_all.deb &&
cd $CWD
if [ $? != 0 ]
then
	echo "error: couldn't create meta package"
	exit 1
fi

echo "creating python package..."
cd ${CWD}/python &&
# debian control files
rm -rf debian &&
mkdir debian &&
# changelog
cat << EOF > debian/changelog &&
$PYPKGNAME ($VERSION) unstable; urgency=low
  * comment here.

 -- $MAINTAINER  $(date '+%a, %d %b %Y %T %z')
EOF
# compat
echo $(dpkg -p debhelper | egrep '^Version:' | cut -f 2 -d ' ' | cut -f 1 -d '.') > debian/compat &&
# control
cat << EOF > debian/control &&
Source: ${PYPKGNAME}
Section: science
Priority: optional
Maintainer: ${MAINTAINER}
Build-Depends: debhelper (>=7.0.0), python-support (>= 0.6), cdbs (>= 0.4.49)
Standards-Version: 3.8.3.0

Package: ${PYPKGNAME}
Architecture: ${ARCH}
Depends: \${misc:Depends}, \${python:Depends}, ${PKGNAME}, ${PYDEPS}
Description: ${PKGNAME} python bindings.
EOF
# copyright
cp ../COPYING debian/copyright &&
# rules
cat << EOF > debian/rules &&
#!/usr/bin/make -f
# -*- makefile -*-

DEB_PYTHON_SYSTEM := pysupport

include /usr/share/cdbs/1/rules/debhelper.mk
include /usr/share/cdbs/1/class/python-distutils.mk
include /usr/share/cdbs/1/rules/simple-patchsys.mk
EOF
chmod a+x debian/rules &&
# pyversion
echo "2.5-" > debian/pyversions &&
# shlibs.local
LIBFILE=$(whereis libecsb | sed 's/\ /\n/g' | egrep "\.so$" | head -n 1) &&
for i in $(ldd ${LIBFILE} | sed 's/^\t//g' | cut -f 1 -d ' ' | sed 's/\.so\.[0-9\.]*$//g')
do
	echo "libecsb 0 $(basename $i)," >> debian/shlibs.local
done &&
LIBFILE=$(whereis libmcss | sed 's/\ /\n/g' | egrep "\.so$" | head -n 1) &&
for i in $(ldd ${LIBFILE} | sed 's/^\t//g' | cut -f 1 -d ' ' | sed 's/\.so\.[0-9\.]*$//g')
do
	echo "libmcss 0 $(basename $i)," >> debian/shlibs.local
done &&
LIBSBML=$(whereis libsbml | sed 's/\ /\n/g' | egrep "\.so$" | head -n 1) &&
for i in $(ldd ${LIBFILE} | sed 's/^\t//g' | cut -f 1 -d ' ' | sed 's/\.so\.[0-9\.]*$//g')
do
	echo "libsbml 4 $(basename $i)," >> debian/shlibs.local
done &&

# make package
cd .. &&
./configure --enable-python=yes &>> ${LOGFILE} &&
cd python &&
make &>> ${LOGFILE} &&
python setup.py sdist --dist-dir=../ &>> ${LOGFILE} &&
dpkg-buildpackage -uc -b -rfakeroot &>> ${LOGFILE} &&
cd ${CWD} &&
rm -rf $TMPDIR
if [ $? != 0 ]
then
	echo "error: couldn't create python binary package"
	exit 1
fi

# make meta package
echo "making python meta package..."
# create control file
mkdir -p $TMPDIR/$PYPKGBASE/DEBIAN &&
cat << EOF > $TMPDIR/$PYPKGBASE/DEBIAN/control &&
Package: $PYPKGBASE
Version: $VERSION
Section: science
Priority: optional
Architecture: all
Depends: $PYPKGNAME
Replaces: $PYPKGBASE (<< $VERSION)
EOF
cat $CTRLFILE | egrep '^%vendor' | sed 's/%vendor/Maintainer:/' >> $TMPDIR/$PYPKGBASE/DEBIAN/control &&
cat $CTRLFILE | egrep '^%description' | sed 's/%description/Description:/' >> $TMPDIR/$PYPKGBASE/DEBIAN/control &&

# make meta package
cd $TMPDIR &&
dpkg-deb --build $PYPKGBASE &>> ${LOGFILE} &&
mv $PYPKGBASE.deb $CWD/${PYPKGBASE}_${VERSION}_all.deb &&
cd $CWD &&
rm -rf $TMPDIR
if [ $? != 0 ]
then
	echo "error: couldn't create python meta package"
	exit 1
fi

# all done
echo "all ${PKGBASE} packages built ok"
